from typing import Optional, cast
from ryft_sdk.client import RyftClient
from ryft_sdk.models.payment_sessions.dto.payment_sessions import (
    PaymentSession,
    PaymentSessions,
)
from ryft_sdk.models.payment_sessions.dto.payment_transactions import (
    PaymentTransaction,
    PaymentTransactions,
)
from ryft_sdk.models.payment_sessions.req.payment_sessions_req import (
    AttemptPaymentSessionRequest,
    ContinuePaymentSessionRequest,
    CreatePaymentSessionRequest,
    UpdatePaymentSessionRequest,
)
from ryft_sdk.models.payment_sessions.req.payment_sessions_transactions_req import (
    CapturePaymentSessionRequest,
    RefundPaymentSessionRequest,
)


class PaymentSessionsClient:
    def __init__(self, client: RyftClient):
        self.client = client
        self.path = "payment-sessions"

    async def create(
        self, req: CreatePaymentSessionRequest, account: Optional[str] = None
    ) -> PaymentSession:
        return cast(
            PaymentSession,
            self.client.post(self.path, cast(dict, req), account=account),
        )

    async def list(
        self,
        startTimestamp: Optional[int] = None,
        endTimestamp: Optional[int] = None,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[str] = None,
        account: Optional[str] = None,
    ) -> PaymentSessions:
        return cast(
            PaymentSessions,
            self.client.get(
                self.path,
                {
                    "startTimestamp": startTimestamp,
                    "endTimestamp": endTimestamp,
                    "ascending": ascending,
                    "limit": limit,
                    "startsAfter": startsAfter,
                },
                account=account,
            ),
        )

    async def get(self, id: str, account: Optional[str] = None) -> PaymentSession:
        return cast(
            PaymentSession, self.client.get(f"{self.path}/{id}", account=account)
        )

    async def update(
        self, id: str, req: UpdatePaymentSessionRequest, account: Optional[str] = None
    ) -> PaymentSession:
        return cast(
            PaymentSession,
            self.client.patch(f"{self.path}/{id}", cast(dict, req), account=account),
        )

    async def attempt_payment(
        self, req: AttemptPaymentSessionRequest, account: Optional[str] = None
    ) -> PaymentSession:
        return cast(
            PaymentSession,
            self.client.post(
                f"{self.path}/attempt-payment", cast(dict, req), account=account
            ),
        )

    async def continue_payment(
        self, req: ContinuePaymentSessionRequest, account: Optional[str] = None
    ) -> PaymentSession:
        return cast(
            PaymentSession,
            self.client.post(
                f"{self.path}/continue-payment", cast(dict, req), account=account
            ),
        )

    async def list_transactions(
        self,
        id: str,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[str] = None,
        account: Optional[str] = None,
    ) -> PaymentTransactions:
        return cast(
            PaymentTransactions,
            self.client.get(
                f"{self.path}/{id}/transactions",
                {"ascending": ascending, "limit": limit, "startsAfter": startsAfter},
                account=account,
            ),
        )

    async def get_transaction(
        self, id: str, transaction_id: str, account: Optional[str] = None
    ) -> PaymentTransaction:
        return cast(
            PaymentTransaction,
            self.client.get(
                f"{self.path}/{id}/transactions/{transaction_id}", account=account
            ),
        )

    async def capture(
        self, id: str, req: CapturePaymentSessionRequest, account: Optional[str] = None
    ) -> PaymentTransaction:
        return cast(
            PaymentTransaction,
            self.client.post(
                f"{self.path}/{id}/captures", cast(dict, req), account=account
            ),
        )

    async def void(self, id: str, account: Optional[str] = None) -> PaymentTransaction:
        return cast(
            PaymentTransaction,
            self.client.post(f"{self.path}/{id}/voids", {}, account=account),
        )

    async def refund(
        self, id: str, req: RefundPaymentSessionRequest, account: Optional[str] = None
    ) -> PaymentTransaction:
        return cast(
            PaymentTransaction,
            self.client.post(
                f"{self.path}/{id}/refunds", cast(dict, req), account=account
            ),
        )



from typing_extensions import Dict, List, NotRequired, TypedDict


class BankAccount(TypedDict):
    bankIdType: NotRequired[str]
    bankId: NotRequired[str]
    bankName: NotRequired[str]
    accountNumberType: str
    last4: str


class PayoutMethod(TypedDict):
    id: str
    bankAccount: BankAccount


class Payout(TypedDict):
    id: str
    paymentsTakenDateFrom: str
    paymentsTakenDateTo: str
    amount: int
    currency: str
    status: str
    scheduleType: str
    payoutMethod: NotRequired[PayoutMethod]
    failureReason: NotRequired[str]
    scheme: NotRequired[str]
    createdTimestamp: int
    scheduledTimestamp: int
    completedTimestamp: NotRequired[int]
    metadata: NotRequired[Dict[str, str]]


class Payouts(TypedDict):
    items: List[Payout]
    paginationToken: NotRequired[str]



from typing_extensions import List, NotRequired, TypedDict
from ryft_sdk.models.address import Address


class PaymentMethodCard(TypedDict):
    scheme: str
    last4: str
    expiryMonth: str
    expiryYear: str


class PaymentMethodChecks(TypedDict):
    avsResponseCode: NotRequired[str]
    cvvResponseCode: NotRequired[str]


class PaymentMethod(TypedDict):
    id: str
    type: str
    customerId: NotRequired[str]
    createdTimestamp: int
    card: NotRequired[PaymentMethodCard]
    billingAddress: NotRequired[Address]
    checks: NotRequired[PaymentMethodChecks]


class PaymentMethods(TypedDict):
    items: List[PaymentMethod]



import unittest
from ryft_sdk.utils import determine_base_url


class TestUtils(unittest.TestCase):
    def test_determine_base_url_with_live_key(self):
        url = determine_base_url("sk_live_example123")
        self.assertEqual(url, "https://api.ryftpay.com/v1")

    def test_determine_base_url_with_test_key(self):
        url = determine_base_url("sk_sandbox_example123")
        self.assertEqual(url, "https://sandbox-api.ryftpay.com/v1")

    def test_determine_base_url_with_other_key(self):
        url = determine_base_url("some_other_key")
        self.assertEqual(url, "https://sandbox-api.ryftpay.com/v1")


if __name__ == "__main__":
    unittest.main()



from typing_extensions import List, NotRequired, TypedDict

from ryft_sdk.models.persons.dto.verification_error import VerificationError


class VerificationRequiredField(TypedDict):
    name: str


class VerificationRequiredDocuments(TypedDict):
    category: str
    types: List[str]
    quantity: int


class PersonVerification(TypedDict):
    status: str
    requiredFields: List[VerificationRequiredField]
    requiredDocuments: VerificationRequiredDocuments
    errors: NotRequired[List[VerificationError]]



from typing_extensions import Dict, NotRequired, TypedDict


class TransferDestinationRequest(TypedDict):
    accountId: str


class CreateTransferRequest(TypedDict):
    amount: int
    currency: str
    source: NotRequired[TransferDestinationRequest]
    destination: NotRequired[TransferDestinationRequest]
    reason: NotRequired[str]
    metadata: NotRequired[Dict[str, str]]



from typing_extensions import Dict, List, NotRequired, TypedDict

from ryft_sdk.models.address import Address
from ryft_sdk.models.shipping_details import ShippingDetails


class CustomerDetails(TypedDict):
    id: NotRequired[str]
    firstName: NotRequired[str]
    lastName: NotRequired[str]
    homePhoneNumber: NotRequired[str]
    mobilePhoneNumber: NotRequired[str]
    metadata: NotRequired[Dict[str, str]]


class CredentialsOnFileUsage(TypedDict):
    initiator: str
    sequence: str


class PreviousPayment(TypedDict):
    id: str


class RebillingDetail(TypedDict):
    amountVariance: str
    numberOfDaysBetweenPayments: int
    totalNumberOfPayments: NotRequired[int]
    currentPaymentNumber: NotRequired[int]
    expiry: NotRequired[int]


class TokenizedDetails(TypedDict):
    id: str
    stored: bool


class Card(TypedDict):
    scheme: str
    last4: str


class Wallet(TypedDict):
    type: str


class Checks(TypedDict):
    avsResponseCode: NotRequired[str]
    cvvResponseCode: NotRequired[str]


class SessionPaymentMethod(TypedDict):
    type: str
    tokenizedDetails: NotRequired[TokenizedDetails]
    card: NotRequired[Card]
    wallet: NotRequired[Wallet]
    billingAddress: NotRequired[Address]
    checks: NotRequired[Checks]


class Fee(TypedDict):
    amount: int


class SplitPaymentDetailItem(TypedDict):
    id: str
    accountId: str
    amount: int
    fee: Fee
    description: str
    metadata: NotRequired[Dict[str, str]]


class SplitPaymentDetail(TypedDict):
    items: List[SplitPaymentDetailItem]


class StatementDescriptor(TypedDict):
    descriptor: str
    city: str


class RequiredAction(TypedDict):
    type: str
    url: str


class OrderDetailsItem(TypedDict):
    reference: str
    name: str
    quantity: int
    unitPrice: int
    taxAmount: int
    totalAmount: int
    discountAmount: int
    productUrl: str
    imageUrl: str


class OrderDetails(TypedDict):
    items: List[OrderDetailsItem]


class PaymentMethodOptions(TypedDict):
    disabled: List[str]


class PaymentSettings(TypedDict):
    paymentMethodOptions: PaymentMethodOptions


class PaymentSession(TypedDict):
    id: str
    amount: int
    currency: str
    paymentType: NotRequired[str]
    entryMode: NotRequired[str]
    customerEmail: NotRequired[str]
    customerDetails: NotRequired[CustomerDetails]
    credentialOnFileUsage: NotRequired[CredentialsOnFileUsage]
    previousPayment: NotRequired[PreviousPayment]
    rebillingDetail: NotRequired[RebillingDetail]
    enabledPaymentMethods: List[str]
    paymentMethod: NotRequired[SessionPaymentMethod]
    platformFee: NotRequired[int]
    splitPaymentDetail: SplitPaymentDetail
    status: str
    metadata: NotRequired[Dict[str, str]]
    clientSecret: str
    lastError: NotRequired[str]
    refundedAmount: int
    statementDescriptor: StatementDescriptor
    requiredAction: NotRequired[RequiredAction]
    returnUrl: str
    authorizationType: NotRequired[str]
    captureFlow: NotRequired[str]
    verifyAccount: NotRequired[bool]
    shippingDetails: NotRequired[ShippingDetails]
    orderDetails: NotRequired[OrderDetails]
    paymentSettings: NotRequired[PaymentSettings]
    createdTimestamp: int
    lastUpdatedTimestamp: int


class PaymentSessions(TypedDict):
    items: List[PaymentSession]
    paginationToken: NotRequired[str]



from typing_extensions import NotRequired, TypedDict


class Address(TypedDict):
    firstName: NotRequired[str]
    lastName: NotRequired[str]
    lineOne: NotRequired[str]
    lineTwo: NotRequired[str]
    city: NotRequired[str]
    country: str
    postalCode: str
    region: NotRequired[str]


class AccountAddress(TypedDict):
    lineOne: str
    lineTwo: NotRequired[str]
    city: NotRequired[str]
    country: str
    postalCode: str
    region: NotRequired[str]



from typing import cast, Optional
from ryft_sdk.client import RyftClient
from ryft_sdk.models.transfers.dto.transfers import Transfer, Transfers
from ryft_sdk.models.transfers.req.transfers_req import CreateTransferRequest


class TransfersClient:
    def __init__(self, client: RyftClient):
        self.client = client
        self.path = "transfers"

    async def create(self, req: CreateTransferRequest) -> Transfer:
        return cast(Transfer, self.client.post(self.path, cast(dict, req)))

    async def list(
        self,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[int] = None,
    ) -> Transfers:
        return cast(
            Transfers,
            self.client.get(
                self.path,
                {
                    "ascending": ascending,
                    "limit": limit,
                    "startsAfter": startsAfter,
                },
            ),
        )

    async def get(self, id: str) -> Transfer:
        return cast(Transfer, self.client.get(f"{self.path}/{id}"))



from typing_extensions import List, NotRequired, TypedDict
from ryft_sdk.models.payment_sessions.dto.payment_sessions import (
    PaymentSessionPaymentMethod,
    SplitPaymentDetail,
)


class PaymentTransaction(TypedDict):
    id: str
    paymentSessionId: str
    amount: int
    currency: str
    type: str
    status: str
    refundedAmount: NotRequired[int]
    platformFee: NotRequired[int]
    platformFeeRefundedAmount: NotRequired[int]
    processingFee: NotRequired[int]
    reason: NotRequired[str]
    captureType: NotRequired[str]
    paymentMethod: NotRequired[PaymentSessionPaymentMethod]
    splitPaymentDetail: NotRequired[SplitPaymentDetail]
    createdTimestamp: int
    lastUpdatedTimestamp: int


class PaymentTransactions(TypedDict):
    items: List[PaymentTransaction]
    paginationToken: NotRequired[str]



from typing import cast, Optional
from ryft_sdk.client import RyftClient
from ryft_sdk.models.accounts.dto.accounts import AccountAuthorization, SubAccount
from ryft_sdk.models.accounts.dto.payouts import Payout, Payouts
from ryft_sdk.models.accounts.req.accounts_req import (
    CreateSubAccountRequest,
    UpdateSubAccountRequest,
)
from ryft_sdk.models.accounts.req.authlink_req import CreateAuthLinkReq
from ryft_sdk.models.accounts.req.payouts_req import CreatePayoutRequest


class AccountsClient:
    def __init__(self, client: RyftClient):
        self.client = client
        self.path = "accounts"

    async def create(self, req: CreateSubAccountRequest) -> SubAccount:
        return cast(SubAccount, self.client.post(self.path, cast(dict, req)))

    async def get(self, id: str) -> SubAccount:
        return cast(SubAccount, self.client.get(f"{self.path}/{id}"))

    async def update(self, id: str, req: UpdateSubAccountRequest) -> SubAccount:
        return cast(SubAccount, self.client.patch(f"{self.path}/{id}", cast(dict, req)))

    async def verify(self, id: str) -> SubAccount:
        return cast(SubAccount, self.client.post(f"{self.path}/{id}/verify", {}))

    async def create_payout(self, id: str, req: CreatePayoutRequest) -> Payout:
        return cast(
            Payout, self.client.post(f"{self.path}/{id}/payouts", cast(dict, req))
        )

    async def list_payouts(
        self,
        id: str,
        start: Optional[int] = None,
        end: Optional[int] = None,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[int] = None,
    ) -> Payouts:
        return cast(
            Payouts,
            self.client.get(
                f"{self.path}/{id}/payouts",
                {
                    "start": start,
                    "end": end,
                    "ascending": ascending,
                    "limit": limit,
                    "startsAfter": startsAfter,
                },
            ),
        )

    async def get_payout(self, id: str, payoutId: str) -> Payout:
        return cast(Payout, self.client.get(f"{self.path}/{id}/payouts/{payoutId}"))

    async def create_auth_link(self, req: CreateAuthLinkReq) -> AccountAuthorization:
        return cast(
            AccountAuthorization,
            self.client.post(f"{self.path}/authorize", cast(dict, req)),
        )



from typing_extensions import List, NotRequired, TypedDict


class ApplePayWebDomain(TypedDict):
    id: str
    domainName: str
    createdTimestamp: int


class ApplePayWebDomains(TypedDict):
    items: List[ApplePayWebDomain]
    paginationToken: NotRequired[str]


class ApplePayWebSession(TypedDict):
    sessionObject: str



from typing import cast, Optional
from ryft_sdk.client import RyftClient
from ryft_sdk.models.accounts.req.payouts_req import CreatePayoutRequest
from ryft_sdk.models.payouts.dto.payouts import Payout, Payouts


class PayoutsClient:
    def __init__(self, client: RyftClient):
        self.client = client

    async def create(self, id: str, req: CreatePayoutRequest) -> Payout:
        return cast(Payout, self.client.post(f"accounts/{id}/payouts", cast(dict, req)))

    async def get(self, id: str, payout_id: str) -> Payout:
        return cast(Payout, self.client.get(f"accounts/{id}/payouts/{payout_id}"))

    async def list(
        self,
        id: str,
        startTimestamp: Optional[int] = None,
        endTimestamp: Optional[int] = None,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[int] = None,
    ) -> Payouts:
        return cast(
            Payouts,
            self.client.get(
                f"accounts/{id}/payouts",
                {
                    "startTimestamp": startTimestamp,
                    "endTimestamp": endTimestamp,
                    "ascending": ascending,
                    "limit": limit,
                    "startsAfter": startsAfter,
                },
            ),
        )



from typing_extensions import Dict, List, NotRequired, TypedDict
from ryft_sdk.models.address import AccountAddress


class DocumentRequest(TypedDict):
    type: str
    front: str
    back: NotRequired[str]
    country: NotRequired[str]


class CreatePersonRequest(TypedDict):
    firstName: str
    middleNames: NotRequired[str]
    lastName: str
    email: str
    dateOfBirth: str
    countryOfBirth: NotRequired[str]
    gender: str
    nationalities: List[str]
    address: AccountAddress
    phoneNumber: str
    businessRoles: List[str]
    documents: List[DocumentRequest]
    metadata: NotRequired[Dict[str, str]]


class UpdatePersonRequest(TypedDict):
    firstName: NotRequired[str]
    middleNames: NotRequired[str]
    lastName: NotRequired[str]
    email: NotRequired[str]
    dateOfBirth: NotRequired[str]
    countryOfBirth: NotRequired[str]
    gender: NotRequired[str]
    nationalities: NotRequired[List[str]]
    address: NotRequired[AccountAddress]
    phoneNumber: NotRequired[str]
    businessRoles: NotRequired[List[str]]
    documents: NotRequired[List[DocumentRequest]]
    metadata: NotRequired[Dict[str, str]]



from typing_extensions import List, NotRequired, TypedDict
from ryft_sdk.models.disputes.dto.disputes import (
    DisputeEvidenceFile,
    DisputeEvidenceTextEntries,
)


class AddDisputeEvidenceRequest(TypedDict):
    text: NotRequired[DisputeEvidenceTextEntries]
    files: NotRequired[DisputeEvidenceFile]


class DeleteDisputeEvidenceRequest(TypedDict):
    text: List[str]
    files: List[str]



from typing import cast, Optional
from ryft_sdk.client import RyftClient
from ryft_sdk.models.files.dto.files import File, Files
from ryft_sdk.models.files.req.files_req import CreateFileRequest


class FilesClient:
    def __init__(self, client: RyftClient):
        self.client = client
        self.path = "files"

    async def list(
        self,
        category: Optional[str] = None,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[str] = None,
    ) -> Files:
        return cast(
            Files,
            self.client.get(
                self.path,
                {
                    "category": category,
                    "ascending": ascending,
                    "limit": limit,
                    "startsAfter": startsAfter,
                },
            ),
        )

    async def get(self, id: str, account: Optional[str] = None) -> File:
        return cast(File, self.client.get(f"{self.path}/{id}", account=account))

    async def create(
        self, req: CreateFileRequest, account: Optional[str] = None
    ) -> File:
        return cast(
            File,
            self.client.upload_file(
                endpoint=self.path,
                file_path=req.get("file"),
                category=req.get("category"),
                account=account,
            ),
        )



from typing import cast, Optional
from ryft_sdk.client import RyftClient
from ryft_sdk.models.deleted_resource_resp import DeletedResourceResp
from ryft_sdk.models.payout_methods.dto.payout_methods import (
    PayoutMethod,
    PayoutMethods,
)
from ryft_sdk.models.payout_methods.req.payout_methods import (
    CreatePayoutMethodRequest,
    UpdatePayoutMethodRequest,
)


class PayoutMethodsClient:
    def __init__(self, client: RyftClient):
        self.client = client

    async def create(self, id: str, req: CreatePayoutMethodRequest) -> PayoutMethod:
        return cast(
            PayoutMethod,
            self.client.post(f"accounts/{id}/payout-methods", cast(dict, req)),
        )

    async def list(
        self,
        id: str,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[str] = None,
    ) -> PayoutMethods:
        return cast(
            PayoutMethods,
            self.client.get(
                f"accounts/{id}/payout-methods",
                {
                    "ascending": ascending,
                    "limit": limit,
                    "startsAfter": startsAfter,
                },
            ),
        )

    async def get(self, id: str, payout_method_id) -> PayoutMethod:
        return cast(
            PayoutMethod,
            self.client.get(f"accounts/{id}/payout-methods/{payout_method_id}"),
        )

    async def update(
        self, id: str, payout_method_id: str, req: UpdatePayoutMethodRequest
    ) -> PayoutMethod:
        return cast(
            PayoutMethod,
            self.client.patch(
                f"accounts/{id}/payout-methods/{payout_method_id}", cast(dict, req)
            ),
        )

    async def delete(self, id: str, payout_method_id: str) -> DeletedResourceResp:
        return cast(
            DeletedResourceResp,
            self.client.delete(f"accounts/{id}/payout-methods/{payout_method_id}", {}),
        )



from typing_extensions import Dict, List, Literal, NotRequired, TypedDict, Union
from ryft_sdk.models.address import AccountAddress


class AccountAuthorization(TypedDict):
    createdTimestamp: int
    expiresTimestamp: int
    url: str


class AccountDocument(TypedDict):
    type: str
    front: str
    back: NotRequired[str]
    status: str
    invalidReason: NotRequired[str]
    country: NotRequired[str]
    assignedTimestamp: int
    lastUpdatedTimestamp: int


class AccountBusiness(TypedDict):
    name: str
    type: str
    registrationNumber: str
    registrationDate: NotRequired[str]
    registeredAddress: AccountAddress
    contactEmail: str
    phoneNumber: NotRequired[str]
    tradingName: NotRequired[str]
    tradingAddress: NotRequired[AccountAddress]
    tradingCountries: NotRequired[List[str]]
    websiteUrl: NotRequired[str]
    documents: List[AccountDocument]


class AccountIndividual(TypedDict):
    firstName: str
    middleNames: NotRequired[str]
    lastName: str
    email: str
    dateOfBirth: str
    countryOfBirth: NotRequired[str]
    gender: Union[Literal["Male"], Literal["Female"]]
    nationalities: List[str]
    address: AccountAddress
    phoneNumber: NotRequired[str]
    documents: List[AccountDocument]


class AccountRequiredField(TypedDict):
    name: str


class AccountRequiredDocument(TypedDict):
    category: str
    types: List[str]
    quantity: int


class AccountError(TypedDict):
    id: str
    code: str
    description: str


class AccountRequiredPerson(TypedDict):
    role: str
    quantity: int


class AccountPerson(TypedDict):
    status: str
    required: List[AccountRequiredPerson]


class AccountVerification(TypedDict):
    status: str
    requiredFields: List[AccountRequiredField]
    requiredDocuments: List[AccountRequiredDocument]
    errors: List[AccountError]
    persons: List[AccountPerson]


class AccountSchedule(TypedDict):
    type: str


class AccountPayout(TypedDict):
    schedule: AccountSchedule


class AccountSettings(TypedDict):
    payouts: AccountPayout


class AccountCapability(TypedDict):
    status: str
    requested: bool
    requiredFields: List[AccountRequiredField]
    disabledReason: NotRequired[str]
    requestedTimestamp: int
    lastUpdatedTimestamp: int


class AccountCapabilities(TypedDict):
    visaPayments: AccountCapability
    mastercardPayments: AccountCapability
    amexPayments: AccountCapability


class AccountTermsOfServiceAcceptance(TypedDict):
    ipAddress: str
    userAgent: NotRequired[str]
    when: int


class AccountTermsOfService(TypedDict):
    acceptance: AccountTermsOfServiceAcceptance


class SubAccount(TypedDict):
    id: str
    type: str
    frozen: bool
    email: NotRequired[str]
    onboardingFlow: str
    entityType: str
    business: NotRequired[AccountBusiness]
    individual: NotRequired[AccountIndividual]
    verification: AccountVerification
    metadata: NotRequired[Dict[str, str]]
    settings: AccountSettings
    capabilities: AccountCapabilities
    termsOfService: NotRequired[AccountTermsOfService]
    createdTimestamp: int



from typing_extensions import Dict, List, NotRequired, TypedDict, Union


class EventCustomer(TypedDict):
    id: NotRequired[str]


class PaymentMethodTokenizedDetails(TypedDict):
    id: str
    stored: bool


class PaymentMethod(TypedDict):
    tokenizedDetails: PaymentMethodTokenizedDetails


class EventData(TypedDict):
    id: str
    accountId: NotRequired[str]
    paymentTransactionId: NotRequired[str]
    amount: NotRequired[int]
    platformFee: NotRequired[Union[str, int]]
    currency: NotRequired[str]
    metadata: NotRequired[Dict[str, str]]
    status: NotRequired[str]
    email: NotRequired[str]
    firstName: NotRequired[str]
    lastName: NotRequired[str]
    defaultPaymentMethod: NotRequired[str]
    customer: NotRequired[EventCustomer]
    paymentMethod: PaymentMethod
    createdTimestamp: int


class EventEndpoint(TypedDict):
    webhookId: str
    acknowledged: bool
    attempts: int


class Event(TypedDict):
    id: str
    eventType: str
    data: EventData
    endpoints: List[EventEndpoint]
    accountId: NotRequired[str]
    createdTimestamp: int


class Events(TypedDict):
    items: List[Event]


class PausePaymentDetail(TypedDict):
    reason: NotRequired[str]
    resumeAtTimestamp: NotRequired[int]
    pausedAtTimestamp: int



from typing_extensions import List, NotRequired, TypedDict


class PlatformFee(TypedDict):
    id: str
    paymentSessionId: str
    amount: int
    paymentAmount: int
    netAmount: int
    currency: str
    fromAccountId: str
    createdTimestamp: int


class PlatformFees(TypedDict):
    items: List[PlatformFee]


class PlatformFeeRefund(TypedDict):
    id: str
    platformFeeId: str
    amount: int
    currency: str
    reason: NotRequired[str]
    status: str
    createdTimestamp: int
    lastUpdatedTimestamp: int


class PlatformFeeRefunds(TypedDict):
    items: List[PlatformFeeRefund]



from typing import cast, Optional
from ryft_sdk.client import RyftClient
from ryft_sdk.models.apple_pay.dto.apple_pay import (
    ApplePayWebDomain,
    ApplePayWebDomains,
    ApplePayWebSession,
)
from ryft_sdk.models.apple_pay.req.apple_pay_req import CreateApplePayWebSessionReq


class ApplePayClient:
    def __init__(self, client: RyftClient):
        self.client = client
        self.domains_path = "apple-pay/web-domains"
        self.sessions_path = "apple-pay/sessions"

    async def register_domain(
        self, domain: str, account_id: Optional[str] = None
    ) -> ApplePayWebDomain:
        return cast(
            ApplePayWebDomain,
            self.client.post(
                self.domains_path,
                {
                    "domainName": domain,
                },
                account_id,
            ),
        )

    async def list_domains(
        self,
        ascending: Optional[bool] = None,
        limit: Optional[int] = None,
        startsAfter: Optional[int] = None,
        account_id: Optional[str] = None,
    ) -> ApplePayWebDomains:
        return cast(
            ApplePayWebDomains,
            self.client.get(
                self.domains_path,
                {
                    "ascending": ascending,
                    "limit": limit,
                    "startsAfter": startsAfter,
                },
                account_id,
            ),
        )

    async def get_domain(
        self, id: str, account_id: Optional[str] = None
    ) -> ApplePayWebDomain:
        return cast(
            ApplePayWebDomain,
            self.client.get(f"{self.domains_path}/{id}", {}, account_id),
        )

    async def delete_domain(
        self, id: str, account_id: Optional[str] = None
    ) -> ApplePayWebDomain:
        return cast(
            ApplePayWebDomain,
            self.client.delete(f"{self.domains_path}/{id}", account_id),
        )

    async def create_session(
        self, req: CreateApplePayWebSessionReq
    ) -> ApplePayWebSession:
        return cast(
            ApplePayWebSession, self.client.post(self.sessions_path, cast(dict, req))
        )
